==> haskell-http-types-0.12.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.12.1
id: http-types-0.12.1-1FEEescNY7H9pB2LVhivNI
key: http-types-0.12.1-1FEEescNY7H9pB2LVhivNI
license: BSD-3-Clause
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
author: Aristid Breitkreuz, Michael Snoyman
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
abi: b54600906e288a2a11c67e3d97adc11c
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-types-0.12.1
hs-libraries: HShttp-types-0.12.1-1FEEescNY7H9pB2LVhivNI
depends:
    base-4.11.1.0 bytestring-0.10.8.2 array-0.5.2.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.12.1-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.12.1
id: http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
key: http-types-0.12.1-II9Izt8nVfhCfceL6igA2T
license: BSD-3-Clause
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
author: Aristid Breitkreuz, Michael Snoyman
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
abi: b23e50a639b630c1d82e921bfca06775
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-types-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-types-0.12.1
hs-libraries: HShttp-types-0.12.1-II9Izt8nVfhCfceL6igA2T
depends:
    base-4.11.1.0 bytestring-0.10.8.2 array-0.5.2.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
